diff --git a/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh b/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
index 8b108f2de95ac6f7013eab195edf155cd540160a..16a381d9e4e458729f7f40f8a54cd59d38e1ebc1 100644
--- a/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
+++ b/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
@@ -77,7 +77,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(LensProblem2p, NonwettingPhase)
+SET_PROP(LensProblem2p, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh b/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
index 48c927a2e72efad09155dfd8b431915b4f8b4af8..cd5a69edaeb51d15451880b6dacb1f3edbe87ac5 100644
--- a/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
+++ b/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
@@ -85,7 +85,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(BuckleyLeverettProblem, NonwettingPhase)
+SET_PROP(BuckleyLeverettProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh b/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
index c0a071074368f950871bfcb6c0e5cd748377d0b6..de6af96249e9b5addc62a75b99e3dbed2691ffd0 100644
--- a/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
+++ b/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
@@ -82,7 +82,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(McWhorterProblem, NonwettingPhase)
+SET_PROP(McWhorterProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/dumux/boxmodels/2p/2pvolumevariables.hh b/dumux/boxmodels/2p/2pvolumevariables.hh
index c48a76dd86fb22e842d71dc97c87d41afe01b3d1..e839039472e95132180e9a2fcfd59c83d1170d59 100644
--- a/dumux/boxmodels/2p/2pvolumevariables.hh
+++ b/dumux/boxmodels/2p/2pvolumevariables.hh
@@ -180,7 +180,7 @@ public:
      * \param phaseIdx The phase index
      */
     Scalar pressure(int phaseIdx) const
-    { return fluidState_.phasePressure(phaseIdx); }
+    { return fluidState_.pressure(phaseIdx); }
 
     /*!
      * \brief Returns temperature inside the sub-control volume.
diff --git a/dumux/decoupled/2p/2pproperties.hh b/dumux/decoupled/2p/2pproperties.hh
index de9ed0395ebcc5d3513fe2bfb90ffbddb7cd20c6..8b779f5804e3ea58519b896abcb6d1bb1f353f24 100644
--- a/dumux/decoupled/2p/2pproperties.hh
+++ b/dumux/decoupled/2p/2pproperties.hh
@@ -93,7 +93,7 @@ NEW_PROP_TAG( EnableCompressibility)
 ;// !< Returns whether compressibility is allowed
 NEW_PROP_TAG( WettingPhase)
 ; //!< The wetting phase for two-phase models
-NEW_PROP_TAG( NonwettingPhase)
+NEW_PROP_TAG( NonWettingPhase)
 ; //!< The non-wetting phase for two-phase models
 NEW_PROP_TAG( FluidSystem )//!< Defines the fluid system
 ;
diff --git a/dumux/material/fluidsystems/2p_system.hh b/dumux/material/fluidsystems/2p_system.hh
index 92268d8cc9bfbd14b1b559490fe91686cc701443..97552c72a5671019b553c39b83260b43f14dbd5e 100644
--- a/dumux/material/fluidsystems/2p_system.hh
+++ b/dumux/material/fluidsystems/2p_system.hh
@@ -39,7 +39,7 @@ namespace Dumux {
 namespace Properties {
 NEW_PROP_TAG(Scalar);
 NEW_PROP_TAG(WettingPhase);
-NEW_PROP_TAG(NonwettingPhase);
+NEW_PROP_TAG(NonWettingPhase);
 };
 
 
@@ -59,7 +59,7 @@ class FluidSystem2P
     typedef FluidSystem2P<TypeTag> ThisType;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
 
 public:
 
@@ -92,7 +92,7 @@ public:
     {
         switch (compIdx) {
         case wCompIdx: return WettingPhase::name();
-        case nCompIdx: return NonwettingPhase::name();
+        case nCompIdx: return NonWettingPhase::name();
         };
         DUNE_THROW(Dune::InvalidStateException, "Invalid component index " << compIdx);
     }
@@ -106,7 +106,7 @@ public:
     {
         switch (compIdx) {
         case wCompIdx: return WettingPhase::molarMass();
-        case nCompIdx: return NonwettingPhase::molarMass();
+        case nCompIdx: return NonWettingPhase::molarMass();
         };
         DUNE_THROW(Dune::InvalidStateException, "Invalid component index " << compIdx);
     }
@@ -131,7 +131,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::density(temperature, pressure);
         case nPhaseIdx:
-            return NonwettingPhase::density(temperature, pressure);
+            return NonWettingPhase::density(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -157,7 +157,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::density(temperature, pressure);
         case nPhaseIdx:
-            return NonwettingPhase::density(temperature, pressure);
+            return NonWettingPhase::density(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -182,7 +182,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::viscosity(temperature, pressure);
         case nPhaseIdx:
-            return NonwettingPhase::viscosity(temperature, pressure);
+            return NonWettingPhase::viscosity(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -207,7 +207,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::enthalpy(temperature, pressure);
         case nPhaseIdx:
-            return NonwettingPhase::enthalpy(temperature, pressure);
+            return NonWettingPhase::enthalpy(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -232,7 +232,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::internalEnergy(temperature, pressure);
         case nPhaseIdx:
-            return NonwettingPhase::internalEnergy(temperature, pressure);
+            return NonWettingPhase::internalEnergy(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/test/boxmodels/2pni/injectionproblem2pni.hh b/test/boxmodels/2pni/injectionproblem2pni.hh
index c5bb45f7a7f12fc59455e8117bf76eb4f7a3bad9..02ac864e427121df14953c78fe6b45b9383de116 100644
--- a/test/boxmodels/2pni/injectionproblem2pni.hh
+++ b/test/boxmodels/2pni/injectionproblem2pni.hh
@@ -90,7 +90,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(InjectionProblem2PNI, NonwettingPhase)
+SET_PROP(InjectionProblem2PNI, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/common/generalproblem/generallensproblem.hh b/test/common/generalproblem/generallensproblem.hh
index 3f7b7275c5f20fe81c4c00bfcb9e6b5dc535f76e..0d6a6fac45d34c5d0df6b6278a04fd8a3c01b777 100644
--- a/test/common/generalproblem/generallensproblem.hh
+++ b/test/common/generalproblem/generallensproblem.hh
@@ -91,7 +91,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(GeneralLensProblem, NonwettingPhase)
+SET_PROP(GeneralLensProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/1p/test_diffusion_problem.hh b/test/decoupled/1p/test_diffusion_problem.hh
index a78d2a28fe823286f2e3e205533573f1d06b2d8d..6b7390bd063cf2ed4360eb1a62e2e713cec46bc9 100644
--- a/test/decoupled/1p/test_diffusion_problem.hh
+++ b/test/decoupled/1p/test_diffusion_problem.hh
@@ -78,7 +78,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(DiffusionTestProblem, NonwettingPhase)
+SET_PROP(DiffusionTestProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2p/test_impes_problem.hh b/test/decoupled/2p/test_impes_problem.hh
index 328c1eee6fda86e3f6e179e8c22f4f76c255d5a7..f0382a7c3e83b19252923541ae919b9896bba0ea 100644
--- a/test/decoupled/2p/test_impes_problem.hh
+++ b/test/decoupled/2p/test_impes_problem.hh
@@ -96,7 +96,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(IMPESTestProblem, NonwettingPhase)
+SET_PROP(IMPESTestProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2p/test_transport_problem.hh b/test/decoupled/2p/test_transport_problem.hh
index a57df89efcc9ac06f1bac285d18c3a818455cc31..05f5bbe752218c5c02a191717054c974958f2aeb 100644
--- a/test/decoupled/2p/test_transport_problem.hh
+++ b/test/decoupled/2p/test_transport_problem.hh
@@ -81,7 +81,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TransportTestProblem, NonwettingPhase)
+SET_PROP(TransportTestProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2padaptive/test_impes_adaptive_problem.hh b/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
index 46e35f178b5c1f4d1a1c352fbf5aeddfc1cc26a3..dfc5fb508b7d0bd2edc3628b2d91926c6ecf49e7 100644
--- a/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
+++ b/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
@@ -97,7 +97,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TestIMPESAdaptiveProblem, NonwettingPhase)
+SET_PROP(TestIMPESAdaptiveProblem, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/tutorial/tutorialproblem_coupled.hh b/tutorial/tutorialproblem_coupled.hh
index c1cfe0ff09eb9893724919bf0b743ffbb1e8b1cd..d90bcfaf2fd0b862e1bfa6087fef9defb97fcb8d 100644
--- a/tutorial/tutorialproblem_coupled.hh
+++ b/tutorial/tutorialproblem_coupled.hh
@@ -83,7 +83,7 @@ public: typedef Dumux::LiquidPhase<Scalar, Dumux::H2O<Scalar> > type; /*@\label{
 };
 
 // Set the non-wetting phase
-SET_PROP(TutorialProblemCoupled, NonwettingPhase)
+SET_PROP(TutorialProblemCoupled, NonWettingPhase)
 {
 private: typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
 public: typedef Dumux::LiquidPhase<Scalar, Dumux::Oil<Scalar> > type; /*@\label{tutorial-coupled:nonwettingPhase}@*/
diff --git a/tutorial/tutorialproblem_decoupled.hh b/tutorial/tutorialproblem_decoupled.hh
index 9150691649d3851d03ea589c0211b5ec30c9812e..16a8493f3d5e2ccf3cf56f29d629bcdefcfa832a 100644
--- a/tutorial/tutorialproblem_decoupled.hh
+++ b/tutorial/tutorialproblem_decoupled.hh
@@ -93,7 +93,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TutorialProblemDecoupled, NonwettingPhase)
+SET_PROP(TutorialProblemDecoupled, NonWettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/dumux/boxmodels/richards/richardspropertydefaults.hh b/dumux/boxmodels/richards/richardspropertydefaults.hh
index 6528ab2bd6a26c8fcaae6334f5079b9a94bb2f0f..bf5c5051c214796039d1711b8eaaeb71a42f73af 100644
--- a/dumux/boxmodels/richards/richardspropertydefaults.hh
+++ b/dumux/boxmodels/richards/richardspropertydefaults.hh
@@ -98,7 +98,7 @@ public:
  *
  * By default this uses the immiscible twophase fluid system. The
  * actual fluids used are specified using in the problem definition by
  * the WettingPhase and NonwettingPhase properties. Be aware that
  * using different fluid systems in conjunction with the Richards
  * model only makes very limited sense.
  */
@@ -113,7 +113,7 @@ SET_TYPE_PROP(BoxRichards, FluidSystem, FluidSystem2P<TypeTag>);
  * if the viscosity of the liquid phase is _much_ lower than the
  * viscosity of the wetting phase.
  */
-SET_PROP(BoxRichards, NonwettingPhase)
+SET_PROP(BoxRichards, NonWettingPhase)
 {
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
     typedef GasPhase<Scalar, N2<Scalar> > type;
@@ -98,7 +98,7 @@ public:
  * By default this uses the immiscible twophase fluid system. The
  * actual fluids used are specified using in the problem definition by
- * the WettingPhase and NonwettingPhase properties. Be aware that
+ * the WettingPhase and NonWettingPhase properties. Be aware that
  * using different fluid systems in conjunction with the Richards
  * model only makes very limited sense.